import React, { Fragment, useEffect, useState } from "react";
import { useAuth0 } from "../react-auth0-spa";
import Api from "../utils/api";

import { makeStyles } from "@material-ui/core/styles";
import Table from "@material-ui/core/Table";
import TableBody from "@material-ui/core/TableBody";
import TableCell from "@material-ui/core/TableCell";
import TableContainer from "@material-ui/core/TableContainer";
import TableHead from "@material-ui/core/TableHead";
import TableRow from "@material-ui/core/TableRow";
import Paper from "@material-ui/core/Paper";

const useStyles = makeStyles({
  table: {
    minWidth: 650,
    overflowY: 'scroll',
  },
  tableContainer: {
    margin: 24
  }
});

const createNumbers = (numbers) => [...Array(31)].map((_value, index) => (numbers ? numbers[index + 1] : index + 1));

function createData({ month, year, ...row }) {
  return { month, year, sunValues: createNumbers(row) };
}

const headerTemplate = {
  year: "Year",
  month: "Měsíc",
  labels: createNumbers()
};

const DataTable = ({ rows }) => {
  const classes = useStyles();
  console.log(classes);
  return (
    <TableContainer className={classes.tableContainer} component={Paper}>
      <Table className={classes.table} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell>{headerTemplate.year}</TableCell>
            <TableCell align="right">{headerTemplate.month}</TableCell>
            {headerTemplate.labels.map((label) => (
              <TableCell key={label}>{label}</TableCell>
            ))}
          </TableRow>
        </TableHead>
        <TableBody>
          {rows.map((data) => {
            const row = createData(data);
            return (
              <TableRow key={row.name}>
                <TableCell component="th" scope="row">
                  {row.year}
                </TableCell>
                <TableCell align="right">{row.month}</TableCell>
                {row.sunValues.map((number, index) => (
                  <TableCell key={`${number}-${index}`}>{number}</TableCell>
                ))}
              </TableRow>
            );
          })}
        </TableBody>
      </Table>
    </TableContainer>
  );
};

const Home = () => {
  const { loading, user } = useAuth0();
  const [data, setData] = useState([]);
  useEffect(() => {
    if (!loading && user) {
      Api.get("rest/sunshine").then((data) => setData(data));
    }
  }, [loading, user]);
  return (
    <Fragment>
      <h1>There will be dragons</h1>
      {!user && <h2>Log in to show some data</h2>}
      {user && <DataTable rows={data} />}
    </Fragment>
  );
};

export default Home;
